@@ -341,9 +341,9 @@ AccountPrivate::AccountPrivate(const std::function<Account *(AccountPrivate *)>
 {
 }
 
-QVector<QString> AccountStoragePrivate::activeAccounts(void) const
+QList<QString> AccountStoragePrivate::activeAccounts(void) const
 {
-    QVector<QString> active;
+    QList<QString> active;
     if (!m_is_still_open) {
         qCDebug(logger) << "Not returning accounts: account storage no longer open";
         return active;
@@ -448,7 +448,7 @@ void AccountStoragePrivate::removeAccounts(const QSet<QString> &accountNames)
 
     DeleteAccounts *job = new DeleteAccounts(m_settings, ids);
     m_actions->queueAndProceed(job, [&ids, job, this](void) -> void {
-        for (const QUuid &id : qAsConst(ids)) {
+        for (const QUuid &id : std::as_const(ids)) {
             Account *account = m_accounts[id];
             QObject::connect(job, &DeleteAccounts::finished, account, &Account::removed);
         }
