@@ -23,10 +23,12 @@ public:
     enum Page {
         Error,
         AddAccount,
+        ImportAccount,
         RenameAccount,
         AccountsOverview,
         SetupPassword,
-        UnlockAccounts
+        UnlockAccounts,
+        ScanQR,
     };
     Q_ENUM(Page)
 public:
@@ -35,9 +37,12 @@ public:
 public Q_SLOTS:
     void push(app::Navigation::Page page, QObject *modelToTransfer);
     void navigate(app::Navigation::Page page, QObject *modelToTransfer);
+    void pop();
+
 Q_SIGNALS:
     void routed(app::Navigation::Page route, QObject *transferred);
     void pushed(app::Navigation::Page route, QObject *transferred);
+    void popped(void);
 
 private:
     QQmlEngine *const m_engine;
